indexStore.BdbIndexStore

|  | ## Cheshire3 Object Model: Class BdbIndexStore

Module indexStore :: Class BdbIndexStore

## Class BdbIndexStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
       baseObjects.IndexStore --+
                                |
                               BdbIndexStore

Known Subclasses:
  C2IndexStore

Instance Methods

__init__(self, session, parent, config) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
_closeIndex(self, session, index)
_openIndex(self, session, index)
_fileFilter(self, x)
_generateFilename(self, index)
_get_internalId(self, session, rec)
_get_externalId(self, session, recordStore, identifier)
fetch_temp_file(self, session, idxid)
begin_indexing(self, session, index) Perform tasks as required before indexing begins, for example setting batch files.
get_indexingPosition(self, session)
commit_indexing(self, session, index) Commit the data to disk from the indexing process.
commit_indexing2(self, session, index, sorted)
create_term(self, session, index, termid, resultSet)
fetch_indexList(self, session) Fetch a list of all indexes stored in this IndexStore.
fetch_indexStats(self, session, index) Fetch statistics (such as size) about the given Index.
contains_index(self, session, index) Does the IndexStore currently store the given Index.
create_index(self, session, index) Create an index in the store.
clean_index(self, session, index) Remove all the terms from an index, but keep the specification.
delete_index(self, session, index) Completely delete an index from the store.
fetch_sortValue(self, session, index, item) Fetch a stored data value for the given record.
store_terms(self, session, index, termhash, record) Store terms in the index for a given record.
delete_terms(self, session, index, terms, record) Delete the given terms from an index, optionally only for a particular record.
fetch_termList(self, session, index, term, numReq=0, relation="", end="", summary=0, reverse=0) Fetch a list of terms for an index.
create_item(self, session, tid, rst, occs, rsitype="SimpleResultSetItem")
fetch_term(self, session, index, term, prox=True) Fetch a single term.
fetch_packed(self, session, index, term)
Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

indexing |
outFiles |
outSortFiles |
storeHash |
storeHashReverse |
sortStoreCxn |
identifierMapCxn |
indexCxn |
reservedLongs |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, parent, config) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### _closeIndex(self, session, index) | source code

### _openIndex(self, session, index) | source code

### _fileFilter(self, x) | source code

### _generateFilename(self, index) | source code

### _get_internalId(self, session, rec) | source code

### _get_externalId(self, session, recordStore, identifier) | source code

### fetch_temp_file(self, session, idxid) | source code

### begin_indexing(self, session, index) | source code
Perform tasks as required before indexing begins, for example setting batch files. Overrides: baseObjects.IndexStore.begin_indexing (inherited documentation)

### get_indexingPosition(self, session) | source code

### commit_indexing(self, session, index) | source code
Commit the data to disk from the indexing process. Overrides: baseObjects.IndexStore.commit_indexing (inherited documentation)

### commit_indexing2(self, session, index, sorted) | source code

### create_term(self, session, index, termid, resultSet) | source code

### fetch_indexList(self, session) | source code
Fetch a list of all indexes stored in this IndexStore. Overrides: baseObjects.IndexStore.fetch_indexList (inherited documentation)

### fetch_indexStats(self, session, index) | source code
Fetch statistics (such as size) about the given Index. Overrides: baseObjects.IndexStore.fetch_indexStats (inherited documentation)

### contains_index(self, session, index) | source code
Does the IndexStore currently store the given Index. Overrides: baseObjects.IndexStore.contains_index (inherited documentation)

### create_index(self, session, index) | source code
Create an index in the store. Overrides: baseObjects.IndexStore.create_index (inherited documentation)

### clean_index(self, session, index) | source code
Remove all the terms from an index, but keep the specification. Overrides: baseObjects.IndexStore.clean_index (inherited documentation)

### delete_index(self, session, index) | source code
Completely delete an index from the store. Overrides: baseObjects.IndexStore.delete_index (inherited documentation)

### fetch_sortValue(self, session, index, item) | source code
Fetch a stored data value for the given record. Overrides: baseObjects.IndexStore.fetch_sortValue (inherited documentation)

### store_terms(self, session, index, termhash, record) | source code
Store terms in the index for a given record. Overrides: baseObjects.IndexStore.store_terms (inherited documentation)

### delete_terms(self, session, index, terms, record) | source code
Delete the given terms from an index, optionally only for a particular record. Overrides: baseObjects.IndexStore.delete_terms (inherited documentation)

### fetch_termList(self, session, index, term, numReq=0, relation="", end="", summary=0, reverse=0) | source code
Fetch a list of terms for an index. numReq: How many terms are wanted. relation: Which order to scan through the index. end: A point to end at (eg between A and B) summary: Only return frequency info, not the pointers to matching records. reverse: Use the reversed index if available (eg 'xedni' not 'index'). Overrides: baseObjects.IndexStore.fetch_termList (inherited documentation)

### create_item(self, session, tid, rst, occs, rsitype="SimpleResultSetItem") | source code

### fetch_term(self, session, index, term, prox=True) | source code
Fetch a single term. Overrides: baseObjects.IndexStore.fetch_term (inherited documentation)

### fetch_packed(self, session, index, term) | source code

Class Variable Details

    ### indexing Value:
        0

    ### outFiles Value:
        {}

    ### outSortFiles Value:
        {}

    ### storeHash Value:
        {}

    ### storeHashReverse Value:
        {}

    ### sortStoreCxn Value:
        {}

    ### identifierMapCxn Value:
        {}

    ### indexCxn Value:
        {}

    ### reservedLongs Value:
        3